==> mysql-8.0_8.0.19.orig.tar.gz: mysql-8.0.19/plugin/x/src/udf/registry.h <==
/* Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2.0,
as published by the Free Software Foundation.

This program is also distributed with certain software (including
but not limited to OpenSSL) that is licensed under separate terms,
as designated in a particular file or component or in included license
documentation.  The authors of MySQL hereby grant you an additional
permission to link the program and your derivative works with the
separately licensed software that they have included with MySQL.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License, version 2.0, for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef PLUGIN_X_SRC_UDF_REGISTRY_H_
#define PLUGIN_X_SRC_UDF_REGISTRY_H_

#include <initializer_list>
#include "plugin/x/src/udf/registrator.h"

#define UDF(name) udf::get_##name##_record()

namespace xpl {
namespace udf {

class Registry {
 public:
  using Record = Registrator::Record;
  using Name_registry = Registrator::Name_registry;
  using Record_list = std::initializer_list<Record>;

  Registry() = default;
  ~Registry() { drop(); }

  void insert(const Record_list &list);
  void drop();

 private:
  Name_registry m_function_names;
};

}  // namespace udf
}  // namespace xpl

#endif  // PLUGIN_X_SRC_UDF_REGISTRY_H_

==> mysql-8.0_8.0.28.orig.tar.gz: mysql-8.0.28/plugin/x/src/udf/registry.h <==
/* Copyright (c) 2018, 2021, Oracle and/or its affiliates.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2.0,
as published by the Free Software Foundation.

This program is also distributed with certain software (including
but not limited to OpenSSL) that is licensed under separate terms,
as designated in a particular file or component or in included license
documentation.  The authors of MySQL hereby grant you an additional
permission to link the program and your derivative works with the
separately licensed software that they have included with MySQL.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License, version 2.0, for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef PLUGIN_X_SRC_UDF_REGISTRY_H_
#define PLUGIN_X_SRC_UDF_REGISTRY_H_

#include <initializer_list>

#include "plugin/x/src/udf/registrator.h"

#define UDF(name) xpl::udf::get_##name##_record()

namespace xpl {
namespace udf {

class Registry {
 public:
  using Record = Registrator::Record;
  using Name_registry = Registrator::Name_registry;
  using Record_list = std::initializer_list<Record>;

  Registry() = default;
  ~Registry() {
    if (!m_function_names.empty()) drop();
  }

  void insert(const Record_list &list);
  void drop();

 private:
  Name_registry m_function_names;
};

}  // namespace udf
}  // namespace xpl

#endif  // PLUGIN_X_SRC_UDF_REGISTRY_H_
